<?php

namespace MakeCommerce\Payment\Gateway\WooCommerce;

trait Banklink {

    /**
     * Reloads banklinks
     * 
     * @since 3.0.0
     */
    public function mc_banklinks_reload( $force = false ) {

        if ( $force || ( defined( 'DOING_AJAX' ) && DOING_AJAX ) ) {

            global $wp_version;
            global $wpdb;
            
            if ( !$this->MK ) {
                return false;
            }
            
            try {
                $shopConfig = $this->MK->getShopConfig( \MakeCommerce::config_request_parameters( $this->id.' '.$this->version ) );
                $methods = $shopConfig->paymentMethods;	
            } catch ( \Exception $e ) {
                error_log( print_r( $e, 1 ) );
                return false;
            }

            $tableName = $wpdb->prefix . MAKECOMMERCE_TABLENAME;
            $sql = "select count(*) as isLogoUrlSet from information_schema.columns where table_name='".$tableName."' and column_name='logo_url'";
            $methodstruct = $wpdb->get_results( $sql );
            if ( $methodstruct[0]->isLogoUrlSet == 0 ) {
                $wpdb->query( 'ALTER TABLE '.$tableName.' ADD COLUMN logo_url varchar(250)' );
            }

            $sql = "select count(*) as min_amount from information_schema.columns where table_name='".$tableName."' and column_name='min_amount'";
            $methodstruct = $wpdb->get_results( $sql );
            if ( $methodstruct[0]->min_amount == 0 ) {
                $wpdb->query( 'ALTER TABLE '.$tableName.' ADD COLUMN min_amount mediumint(9) default 0' );
            }

            $sql = "select count(*) as max_amount from information_schema.columns where table_name='".$tableName."' and column_name='max_amount'";
            $methodstruct = $wpdb->get_results( $sql );
            if ( $methodstruct[0]->max_amount == 0 ) {
                $wpdb->query( 'ALTER TABLE '.$tableName.' ADD COLUMN max_amount mediumint(9) default 0' );
            }

            $wpdb->query( 'TRUNCATE TABLE '.$tableName );
            
            if ( isset( $methods->banklinks ) ) {
                foreach( $methods->banklinks as $method ) {
                    $wpdb->insert( $tableName, array( 'type' => 'banklink', 'country' => $method->country, 'name' => $method->name, 'url' => $method->url, 'logo_url' => $method->logo_url ) );
                }

                $updated = true;
            }
            
            if ( isset( $methods->cards ) ) {
                foreach( $methods->cards as $method ) {
                    $wpdb->insert( $tableName, array( 'type' => 'card', 'name' => $method->name, 'logo_url' => $method->logo_url ) );
                }

                $updated = true;
            }

            if ( isset( $methods->other ) ) {
                foreach( $methods->other as $method ) {
                    $wpdb->insert( $tableName, array( 'type' => 'other', 'country' => $method->country, 'name' => $method->name, 'url' => $method->url, 'logo_url' => $method->logo_url ) );
                }

                $updated = true;
            }

            if ( isset( $methods->payLater ) ) {
                foreach( $methods->payLater as $method ) {
                    //not all payLater accounts have a max_amount parameter. Set them to NULL to avoid notice's
                    if ( !isset( $method->max_amount ) ) {
                        $method->max_amount = NULL;
                    }

                    $wpdb->insert( $tableName, array( 'type' => 'payLater', 'country' => $method->country, 'name' => $method->name, 'url' => $method->url, 'logo_url' => $method->logo_url, 'min_amount' => $method->min_amount, 'max_amount' => $method->max_amount ) );
                }

                $updated = true;
            }

            if ( isset( $shopConfig ) && strlen( $shopConfig->name ) ) {
                update_option( 'mc_shop_name', $shopConfig->name );
            }

            if ( $updated ) {
                update_option( 'mc_banklinks_api_type', get_option( 'mk_api_type', false) );
            }

            if ( $force ) {
                $this->methods->load_methods();

                return $updated;
            }
            
            if ( $updated ) {
                wp_send_json( array( 'success' => 1, 'data' => __( 'Update successfully completed!', 'wc_makecommerce_domain' ) ) );

                exit;
            }
            
            wp_send_json( array( 'success' => 0, 'data' => __( 'There was an error with your update. Please try again.', 'wc_makecommerce_domain' ) ) );

            exit; 
        }

        die();
    }

    /**
     * Creates banklinks reload button
     * 
     * @since 3.0.0
     */
    public function generate_mc_banklinks_reload_html( $key, $data ) {

        $field    = $this->get_field_key( $key );
        $defaults = array(
            'title'             => '',
            'disabled'          => false,
            'class'             => '',
            'css'               => '',
            'placeholder'       => '',
            'type'              => 'text',
            'desc_tip'          => false,
            'description'       => '',
            'custom_attributes' => array()
        );
    
        $data = wp_parse_args( $data, $defaults );
    
        ob_start();
        ?>
        <tr valign="top">
            <th scope="row" class="titledesc">
                <label for="<?php echo esc_attr( $field ); ?>"><?php echo wp_kses_post( $data['title'] ); ?></label>
                <?php echo $this->get_tooltip_html( $data ); ?>
            </th>
            <td class="forminp">
                <fieldset>
                    <legend class="screen-reader-text"><span><?php echo wp_kses_post( $data['title'] ); ?></span></legend>
                    <input id="mc_banklinks_reload" class="button <?php echo esc_attr( $data['class'] ); ?>" type="button" name="<?php echo esc_attr( $field ); ?>" id="<?php echo esc_attr( $field ); ?>" style="<?php echo esc_attr( $data['css'] ); ?>" value="<?php echo esc_attr( $data['description'] ); ?>" placeholder="<?php echo esc_attr( $data['placeholder'] ); ?>" <?php disabled( $data['disabled'], true ); ?> <?php echo $this->get_custom_attribute_html( $data ); ?> />
                    <script type="text/javascript">
                    jQuery('input#mc_banklinks_reload').on('click', function() {
                            init_mc_loading();
                            jQuery.ajax({
                                url: '<?php echo get_site_url(); ?>/wp-admin/admin-ajax.php',
                                type: 'POST',
                                data: 'action=mc_banklinks_reload',
                                success: function (output) {
                                    if(output.data) {
                                        alert(output.data);
                                    } else {
                                        alert('<?php echo __('There was an error with your update. Please try again.', 'wc_makecommerce_domain'); ?>');
                                    }
                                },
                                complete: function() { stop_mc_loading(); }
                            });
                    });
                    
                    function init_mc_loading() {
                        jQuery('input#mc_banklinks_reload').attr('disabled', 'disabled');
                    }
                    
                    function stop_mc_loading() {
                        jQuery('input#mc_banklinks_reload').removeAttr('disabled');
                    }
                    </script>
                </fieldset>
            </td>
        </tr>
        <?php
    
        return ob_get_clean();
    }
}