<?php

namespace MakeCommerce\Payment\Gateway\WooCommerce;

trait Creditcard {

    /**
     * Credit card pending payment page.
     * 
     * @since 3.0.0
     */
    public function receipt_page( $orderId ) {

        $order = new \WC_Order( $orderId );

        if ( substr( get_post_meta( $orderId, '_makecommerce_preselected_method', true ), 0, 5 ) == 'card_' && $order->get_status() == 'pending' ) {

            echo "<br>".__( 'The order is still awaiting your payment', 'wc_makecommerce_domain' )."<br>";
            echo $this->generateCardForm( $order );
        }
    }

    /**
     * Generates credit card payment form
     * 
     * @since 3.0.0
     */
    public function generateCardForm( $orderId ) {

        $order = new \WC_Order( $orderId );

        $has_subscription = function_exists( 'wcs_order_contains_subscription' ) && wcs_order_contains_subscription( $order );

        $scriptSrc = htmlspecialchars( $this->MK->getEnvUrls()->checkoutjsUrl.'checkout.js' );

        $transactionId = get_post_meta( $order->get_id(), '_makecommerce_transaction_id', true );

        $idReference = $order->get_id();

        $jsParams = array(
            'key' => $this->MK->getPublishableKey(),
            'transaction' => $transactionId,
            'selector' => '#submit_banklinkmakecommerce_payment_form',
            'amount' => sprintf( "%.2F", $order->get_total() ),
            'locale' => \MakeCommerce\i18n::get_two_char_locale(),
            'open-on-load' => 'true',
            'client-name' => ( $this->settings['cc_pass_cust_data'] == 'yes' ? ( string ) ( ( method_exists( $order, 'get_billing_first_name' )  ? $order->get_billing_first_name() : $order->billing_first_name ) . ' ' . ( method_exists( $order, 'get_billing_last_name' ) ? $order->get_billing_last_name() : $order->billing_last_name ) ) : '' ),
            'email' => ( $this->settings['cc_pass_cust_data'] == 'yes' ? ( string ) ( method_exists( $order, 'get_billing_email' )  ? $order->get_billing_email() : $order->billing_email ) : '' ),
            'name' => get_option( 'mc_shop_name', '' ),
            'description' => __( 'Order', 'woocommerce' ) . '&nbsp;' . ( string ) $idReference,
            'completed' => 'makecommerce_cc_complete',
            'currency' => method_exists( $order, 'get_currency' ) ? $order->get_currency() : $order->currency, // $transaction->currency, // 'EUR',
            'backdrop-close' => 'false',
        );

        if ( $has_subscription ) {

            $jsParams['recurring-required'] = 'true';
            $jsParams['recurring-title'] = __( 'Pay for subscription', 'wc_makecommerce_domain' );
            $jsParams['recurring-description'] = __( 'This order contains subscriptions', 'wc_makecommerce_domain' );
            $jsParams['recurring-confirmation'] = __( 'I agree that my card will be recurringly billed by this store', 'wc_makecommerce_domain' );
        }

        ?>
        <script type="text/javascript">

        function makecommerce_cc_complete(data) {
                if(data.paymentToken) {
                    jQuery('div.mc-processing-message').show();

                    var submitform = jQuery('<form action="<?php echo $this->payment_return_url; ?>" method="POST" style="display: none;"><input type="submit"/><input type="hidden" name="transaction" value="<?php echo $transactionId; ?>" /></form>');
                    for(var key in data) {
                    submitform.append(jQuery('<input type="hidden" name="'+key+'" />').val(data[key])); 
                    }
                    jQuery('body').append(submitform);
                    submitform.submit();
                }
        }
        </script>
        <form id="cc_form" >
            <input type="submit" class="button-alt" id="submit_banklinkmakecommerce_payment_form" value="<?php echo __( 'Pay with credit card', 'wc_makecommerce_domain' ); ?>" />				
            <script type="text/javascript" src="<?php echo $scriptSrc; ?>" <?php echo $this->_toHtmlAttributes( $jsParams ); ?>></script>
        </form>
        <div class="mc-processing-message"><img src="<?php echo plugins_url( '/images/loading.png', __FILE__ ); ?>"/> <?php echo __( 'Please wait, processing payment...', 'wc_makecommerce_domain' ); ?></div>
        <?php
    }
    
    /**
     * Converts array to HTML values, used by creditcard form
     * 
     * @since 3.0.0
     */
    protected function _toHtmlAttributes( $input ) {

        $result = array();
        
        foreach ( $input as $key => $value ) {
            $result[] = 'data-' . htmlspecialchars( $key ) . '=' . '"' . htmlspecialchars( $value ) . '"';
        }

        return implode( ' ', $result );
    }
}