<?php

namespace MakeCommerce\Shipping\Method\Courier;

/**
 * Specifics for Smartpost courier shipping method
 * 
 * @since 3.0.0
 */

class Smartpost extends \MakeCommerce\Shipping\Method\Courier {

    public $carrier = "Smartpost";
    public $service_name = "eservice.smartpost.ee";
    public $default_price = "4.95";
    public $default_max_weight = "60";

    /**
     * Loads all form fields specific to this shipping method
     * 
     * @since 3.0.0
     */
    public function initialize_method_form_fields() {

        //Nothing to see here, move along
    }

    /**
     * Set method specific hooks/filters
     * 
     * @since 3.0.0
     */
    public function set_method_hooks() {

        add_filter( 'woocommerce_review_order_after_shipping' , array( $this, 'add_smartpost_courier_checkout_fields' ) );
        add_action( 'woocommerce_checkout_update_order_meta', array( $this, 'add_order_meta' ) );
    }

    /**
     * Adds courier arrival time select option to checkout fields
     * 
     * @since 3.0.0
     */
    public function add_smartpost_courier_checkout_fields( $fragment ) {

        echo '
        <tr style="display: none;" class="parcel_machine_checkout parcel_machine_checkout_courier_' . mb_strtolower($this->ext ) . '">
            <td colspan="2">
                <p class="form-row" id="' . esc_attr( $this->id ) . '_field">
                    <label class="courier_arrival_time_window_label">'.__('Pick courier arrival time window', 'wc_makecommerce_domain').'</label>
            
                    <select class="select parcel-machine-select-box-time" name="' . esc_attr( $this->id ) . '" id="' . esc_attr( $this->id ) . '">
                        <option value="1">' . __( 'Any time', 'wc_makecommerce_domain' ) . '</option>
                        <option value="2">' . __( 'Worktime (09:00..17:00)', 'wc_makecommerce_domain' ) . '</option>
                        <option value="3">' . __( 'After worktime (17:00..21:00)', 'wc_makecommerce_domain' ) . '</option>
                    </select>
                </p>
            </td>
        </tr>
        ';
    }

    /**
     * Adds delivery time option to order metadata
     * 
     * @since 3.0.0
     */
    public function add_order_meta( $order_id ) {

        if ( !empty( $_POST[$this->id] ) ) {
            update_post_meta( $order_id, '_delivery_time', sanitize_text_field( $_POST[$this->id] ) );
        }
    }
}