<?php

namespace MakeCommerce\Shipping\Method\ParcelMachine;

/**
 * Omniva parcelmachine shippinh method.
 * Defines all Omniva specific options.
 * 
 * @since 3.0.0
 */

class Omniva extends \MakeCommerce\Shipping\Method\ParcelMachine {
    
    public $carrier = "Omniva";
    public $service_name = "Omniva web services";
    public $type = "apt";
    public $default_price = "5.00";
    public $default_max_weight = "30";

    //LV, LT
    public array $valid_phonenumber_country_codes = array(
        "371",
        "370"
    );
    
    /**
     * Loads all form fields specific to this shipping method
     * 
     * @since 3.0.0
     */
    public function initialize_method_form_fields() {

        //option if we are using MakeCommerce API or Omniva API for shipment registrations 
        $this->form_fields['use_mk_contract'] = array(
            'type' => 'select',
            'title' => __( 'Contract', 'wc_makecommerce_domain' ),
            'options' => array(
                false => __( 'use my own Omniva contract', 'wc_makecommerce_domain' ),
                true => __( 'use MakeCommerce transport mediation service', 'wc_makecommerce_domain' ),
                ),
            'default' => false,
            'description' => '',
        );
        
        //Verifies if you can use MakeCommerce as shipment mediation service
        $this->form_fields['verify_feature_swc'] = array(
            'type' => 'verify_feature_swc',
            'title' => __( 'Verify service status', 'wc_makecommerce_domain' ),
            'description' => __( 'You must enable the Transport mediation service before using it.', 'wc_makecommerce_domain' ),
            'desc_tip' => __( 'This will check if the Transport mediation service has been enabled for your shop.', 'wc_makecommerce_domain' ),
            'placeholder'  => __( 'Verify', 'wc_makecommerce_domain' ),
        );
        
        $this->form_fields['service_carrier'] = array(
            'type' => 'select',
            'title' => __( 'Integration country', 'wc_makecommerce_domain' ),
            'options' => array(
                "OMNIVA" => __( 'Estonia', 'wc_makecommerce_domain' ),
                "OMNIVA_LV" => __( 'Latvia', 'wc_makecommerce_domain' ),
                "OMNIVA_LT" => __( 'Lithuania', 'wc_makecommerce_domain' ),
                ),
            'default' => "ee",
            'description' => __( "Which country's carrier gave you the credentials", 'wc_makecommerce_domain' ),
        );
    }

    /**
     * Generates HTML for checking MakeCommerce shipment mediation availability
     * 
     * @since 3.0.0
     */
    public function generate_verify_feature_swc_html( $key, $data ) {

        $field = $this->get_field_key( $key );
        $defaults = array(
            'title'             => '',
            'disabled'          => false,
            'class'             => '',
            'css'               => '',
            'placeholder'       => '',
            'type'              => 'text',
            'desc_tip'          => false,
            'description'       => '',
            'custom_attributes' => array()
        );

        $data = wp_parse_args( $data, $defaults );

        ob_start();
        ?>

        <tr valign="top">
            <th scope="row" class="titledesc">
                <label for="<?php echo esc_attr( $field ); ?>"><?php echo wp_kses_post( $data['title'] ); ?></label>
                <?php echo $this->get_tooltip_html( $data ); ?>
            </th>
            <td class="forminp">
                <fieldset>
                    <legend class="screen-reader-text"><span><?php echo wp_kses_post( $data['title'] ); ?></span></legend>
                    <input id="verify_feature_swc" class="button <?php echo esc_attr( $data['class'] ); ?>" type="button" name="<?php echo esc_attr( $field ); ?>" id="<?php echo esc_attr( $field ); ?>" style="<?php echo esc_attr( $data['css'] ); ?>" value="<?php echo esc_attr( $data['placeholder'] ); ?>" placeholder="<?php echo esc_attr( $data['placeholder'] ); ?>" <?php disabled( $data['disabled'], true ); ?> <?php echo $this->get_custom_attribute_html( $data ); ?> /> 
                    <script type="text/javascript">
                    jQuery('input#verify_feature_swc').on('click', function() {
                            init_mc_loading();
                            jQuery.ajax({
                                url: '<?php echo get_site_url(); ?>/wp-admin/admin-ajax.php',
                                type: 'POST',
                                data: 'action=verify_feature_swc',
                                success: function (output) {
                                    if (output) {
                                        if (output.feature_status == true) {
                                            alert('<?php echo __('There Transport Mediation service is already enabled for your Shop. You are good to go!', 'wc_makecommerce_domain'); ?>');
                                        } else {
                                            alert('<?php echo __('There Transport Mediation service is NOT ENABLED enabled for your Shop. Please go to Merchant Portal to activate it!', 'wc_makecommerce_domain'); ?>');
                                        }
                                        
                                    } else {
                                        alert('<?php echo __('There was an error with your request. Please try again.', 'wc_makecommerce_domain'); ?>');
                                    }
                                },
                                complete: function() { stop_mc_loading(); }
                            });
                    });
                    
                    function init_mc_loading() {
                        jQuery('input#verify_feature_swc').attr('disabled', 'disabled');
                    }
                    
                    function stop_mc_loading() {
                        jQuery('input#verify_feature_swc').removeAttr('disabled');
                    }
                    </script>
                </fieldset>
            </td>
        </tr>
        <?php

        return ob_get_clean();
    }
}